@@ -10,7 +10,7 @@ C
 C     THIS SUBPROGRAM IS MACHINE-DEPENDENT.
 C     VERSION FOR CDC SYSTEMS USING 6-12 BIT REPRESENTATIONS.
       CHARACTER CA(*)
-      CHARACTER *1 CB
+      CHARACTER (LEN=1) :: CB
       INTEGER ICIRFX
       DATA ICIRFX/62/
 C     SEE IF THE FIRST CHAR. IN STRING CA EQUALS STRING CB. 
